==> verticalpodautoscaler-model-v1-5.10.2-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/HistogramCheckpointFluentImpl.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class HistogramCheckpointFluentImpl<A extends io.fabric8.verticalpodautoscaler.api.model.v1.HistogramCheckpointFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.verticalpodautoscaler.api.model.v1.HistogramCheckpointFluent<A>{
  public HistogramCheckpointFluentImpl() {
  }
  public HistogramCheckpointFluentImpl(io.fabric8.verticalpodautoscaler.api.model.v1.HistogramCheckpoint instance) {
    this.withBucketWeights(instance.getBucketWeights()); 
    this.withReferenceTimestamp(instance.getReferenceTimestamp()); 
    this.withTotalWeight(instance.getTotalWeight()); 
  }
  private java.util.Map<java.lang.Integer,java.lang.Long> bucketWeights;
  private java.lang.String referenceTimestamp;
  private java.lang.Object totalWeight;
  public A addToBucketWeights(java.lang.Integer key,java.lang.Long value) {
    if(this.bucketWeights == null && key != null && value != null) { this.bucketWeights = new java.util.LinkedHashMap<java.lang.Integer,java.lang.Long>(); }
    if(key != null && value != null) {this.bucketWeights.put(key, value);} return (A)this;
  }
  public A addToBucketWeights(java.util.Map<java.lang.Integer,java.lang.Long> map) {
    if(this.bucketWeights == null && map != null) { this.bucketWeights = new java.util.LinkedHashMap<java.lang.Integer,java.lang.Long>(); }
    if(map != null) { this.bucketWeights.putAll(map);} return (A)this;
  }
  public A removeFromBucketWeights(java.lang.Integer key) {
    if(this.bucketWeights == null) { return (A) this; }
    if(key != null && this.bucketWeights != null) {this.bucketWeights.remove(key);} return (A)this;
  }
  public A removeFromBucketWeights(java.util.Map<java.lang.Integer,java.lang.Long> map) {
    if(this.bucketWeights == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.bucketWeights != null){this.bucketWeights.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.Integer,java.lang.Long> getBucketWeights() {
    return this.bucketWeights;
  }
  public <K,V>A withBucketWeights(java.util.Map<java.lang.Integer,java.lang.Long> bucketWeights) {
    if (bucketWeights == null) { this.bucketWeights =  null;} else {this.bucketWeights = new java.util.LinkedHashMap<java.lang.Integer,java.lang.Long>(bucketWeights);} return (A) this;
  }
  public java.lang.Boolean hasBucketWeights() {
    return this.bucketWeights != null;
  }
  public java.lang.String getReferenceTimestamp() {
    return this.referenceTimestamp;
  }
  public A withReferenceTimestamp(java.lang.String referenceTimestamp) {
    this.referenceTimestamp=referenceTimestamp; return (A) this;
  }
  public java.lang.Boolean hasReferenceTimestamp() {
    return this.referenceTimestamp != null;
  }
  
  /**
   * Method is deprecated. use withReferenceTimestamp instead.
   */
  @java.lang.Deprecated
  public A withNewReferenceTimestamp(java.lang.String arg0) {
    return (A)withReferenceTimestamp(new String(arg0));
  }
  public java.lang.Object getTotalWeight() {
    return this.totalWeight;
  }
  public A withTotalWeight(java.lang.Object totalWeight) {
    this.totalWeight=totalWeight; return (A) this;
  }
  public java.lang.Boolean hasTotalWeight() {
    return this.totalWeight != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HistogramCheckpointFluentImpl that = (HistogramCheckpointFluentImpl) o;
    if (bucketWeights != null ? !bucketWeights.equals(that.bucketWeights) :that.bucketWeights != null) return false;
    if (referenceTimestamp != null ? !referenceTimestamp.equals(that.referenceTimestamp) :that.referenceTimestamp != null) return false;
    if (totalWeight != null ? !totalWeight.equals(that.totalWeight) :that.totalWeight != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(bucketWeights,  referenceTimestamp,  totalWeight,  super.hashCode());
  }
  
}

==> verticalpodautoscaler-model-v1-5.12.2-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/HistogramCheckpointFluentImpl.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import java.lang.String;
import java.lang.Double;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class HistogramCheckpointFluentImpl<A extends io.fabric8.verticalpodautoscaler.api.model.v1.HistogramCheckpointFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.verticalpodautoscaler.api.model.v1.HistogramCheckpointFluent<A>{
  public HistogramCheckpointFluentImpl() {
  }
  public HistogramCheckpointFluentImpl(io.fabric8.verticalpodautoscaler.api.model.v1.HistogramCheckpoint instance) {
    this.withBucketWeights(instance.getBucketWeights()); 
    this.withReferenceTimestamp(instance.getReferenceTimestamp()); 
    this.withTotalWeight(instance.getTotalWeight()); 
  }
  private java.util.Map<java.lang.Integer,java.lang.Long> bucketWeights;
  private java.lang.String referenceTimestamp;
  private java.lang.Double totalWeight;
  public A addToBucketWeights(java.lang.Integer key,java.lang.Long value) {
    if(this.bucketWeights == null && key != null && value != null) { this.bucketWeights = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.bucketWeights.put(key, value);} return (A)this;
  }
  public A addToBucketWeights(java.util.Map<java.lang.Integer,java.lang.Long> map) {
    if(this.bucketWeights == null && map != null) { this.bucketWeights = new java.util.LinkedHashMap(); }
    if(map != null) { this.bucketWeights.putAll(map);} return (A)this;
  }
  public A removeFromBucketWeights(java.lang.Integer key) {
    if(this.bucketWeights == null) { return (A) this; }
    if(key != null && this.bucketWeights != null) {this.bucketWeights.remove(key);} return (A)this;
  }
  public A removeFromBucketWeights(java.util.Map<java.lang.Integer,java.lang.Long> map) {
    if(this.bucketWeights == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.bucketWeights != null){this.bucketWeights.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.Integer,java.lang.Long> getBucketWeights() {
    return this.bucketWeights;
  }
  public <K,V>A withBucketWeights(java.util.Map<java.lang.Integer,java.lang.Long> bucketWeights) {
    if (bucketWeights == null) { this.bucketWeights =  null;} else {this.bucketWeights = new java.util.LinkedHashMap(bucketWeights);} return (A) this;
  }
  public java.lang.Boolean hasBucketWeights() {
    return this.bucketWeights != null;
  }
  public java.lang.String getReferenceTimestamp() {
    return this.referenceTimestamp;
  }
  public A withReferenceTimestamp(java.lang.String referenceTimestamp) {
    this.referenceTimestamp=referenceTimestamp; return (A) this;
  }
  public java.lang.Boolean hasReferenceTimestamp() {
    return this.referenceTimestamp != null;
  }
  
  /**
   * Method is deprecated. use withReferenceTimestamp instead.
   */
  @java.lang.Deprecated
  public A withNewReferenceTimestamp(java.lang.String arg0) {
    return (A)withReferenceTimestamp(new String(arg0));
  }
  public java.lang.Double getTotalWeight() {
    return this.totalWeight;
  }
  public A withTotalWeight(java.lang.Double totalWeight) {
    this.totalWeight=totalWeight; return (A) this;
  }
  public java.lang.Boolean hasTotalWeight() {
    return this.totalWeight != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HistogramCheckpointFluentImpl that = (HistogramCheckpointFluentImpl) o;
    if (bucketWeights != null ? !bucketWeights.equals(that.bucketWeights) :that.bucketWeights != null) return false;
    if (referenceTimestamp != null ? !referenceTimestamp.equals(that.referenceTimestamp) :that.referenceTimestamp != null) return false;
    if (totalWeight != null ? !totalWeight.equals(that.totalWeight) :that.totalWeight != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(bucketWeights,  referenceTimestamp,  totalWeight,  super.hashCode());
  }
  
}
